GUI
===
.. automodule:: axoden.gui

Streamlit pdf utility functions
===============================
This section is only relevant if you want to change or extend the streamlit app functionality.

.. automodule:: axoden.gui.streamlit_app.pdf_utils
    :members:

Streamlit app utility functions
===============================
This section is only relevant if you want to change or extend the streamlit app functionality.

.. automodule:: axoden.gui.streamlit_app.app_utils
    :members: